@@ -146,8 +146,7 @@
 #' scen <- demoScen[[2]]
 #'
 #' # landing set 5 of scenario 2, as matrix:
-#' land.mat  <- scen$landings.points[scen$landings.points$set==5,] |>
-#'   sf::st_coordinates()
+#' land.mat  <- sf::st_coordinates(scen$landings.points[scen$landings.points$set==5,])
 #'
 #' prRes <- projectRoads(land.mat, scen$cost.rast, scen$road.rast, "snap",
 #'                       plotRoads = doPlots, mainTitle = "Scen 2: Matrix-Snap")
@@ -381,11 +380,12 @@ setMethod(
     if(geoColInL != attr(sim$landings, "sf_column")){
       sim$landings <- rename(sim$landings, geoColInL = .data$geometry)
     }
-
-    if(geoColInR != attr(sim$roads, "sf_column")){
-      sim$roads <- rename(sim$roads, geoColInR = .data$geometry)
+    if(is(sim$roads, "sf")){
+      if(geoColInR != attr(sim$roads, "sf_column")){
+        sim$roads <- rename(sim$roads, geoColInR = .data$geometry)
+      }
     }
-
+    
     # reset landings to include all input landings
     sim$landings <- sim$landingsIn
     rm("landingsIn", envir = sim)
